@@ -199,39 +199,6 @@ class TestSTACKITChatGenerator:
         assert len(response["replies"]) == 1
         assert [isinstance(reply, ChatMessage) for reply in response["replies"]]
 
-    def test_check_abnormal_completions(self, caplog):
-        component = STACKITChatGenerator(
-            model="neuralmagic/Meta-Llama-3.1-8B-Instruct-FP8", api_key=Secret.from_token("test-api-key")
-        )
-        messages = [
-            ChatMessage.from_assistant(
-                "", meta={"finish_reason": "content_filter" if i % 2 == 0 else "length", "index": i}
-            )
-            for i, _ in enumerate(range(4))
-        ]
-
-        for m in messages:
-            try:
-                # Haystack >= 2.9.0
-                component._check_finish_reason(m.meta)
-            except AttributeError:
-                # Haystack < 2.9.0
-                component._check_finish_reason(m)
-
-        # check truncation warning
-        message_template = (
-            "The completion for index {index} has been truncated before reaching a natural stopping point. "
-            "Increase the max_tokens parameter to allow for longer completions."
-        )
-
-        for index in [1, 3]:
-            assert caplog.records[index].message == message_template.format(index=index)
-
-        # check content filter warning
-        message_template = "The completion for index {index} has been truncated due to the content filter."
-        for index in [0, 2]:
-            assert caplog.records[index].message == message_template.format(index=index)
-
     @pytest.mark.skipif(
         not os.environ.get("STACKIT_API_KEY", None),
         reason="Export an env var called STACKIT_API_KEY containing the API key to run this test.",
